@@ -121,7 +121,6 @@ let ignored_expr_must_be_annotated ignored_reason (expr : Parsetree.expression)
   (* no need to warn people trying to silence other warnings *)
   | Pexp_construct _
   | Pexp_ident _
-  | Pexp_fun _
   | Pexp_function _ -> ()
   | _ -> f ~loc:expr.pexp_loc (Missing_type_annotation ignored_reason)
 ;;
@@ -265,7 +264,7 @@ let iter_style_errors ~f =
     inherit Ast_traverse.iter as super
 
     method! attribute ({ attr_name = name; attr_payload = payload; attr_loc = _ } as attr)
-      =
+        =
       let loc = loc_of_attribute attr in
       if !require_dated_deprecation && is_deprecated name.txt
       then (
@@ -337,7 +336,7 @@ let iter_style_errors ~f =
       match t.pstr_desc with
       | Pstr_eval (_, _)
         when (not allow_toplevel_expression)
-          && not (is_mlt_or_mdx t.pstr_loc.Location.loc_start.Lexing.pos_fname) ->
+             && not (is_mlt_or_mdx t.pstr_loc.Location.loc_start.Lexing.pos_fname) ->
         errorf ~loc:t.pstr_loc "Toplevel expression are not allowed here."
       | Pstr_attribute a ->
         (match Invalid_ocamlformat_attribute.kind a with
@@ -402,12 +401,21 @@ module Comments_checking = struct
     || String.is_prefix s ~prefix:"JS-only"
   ;;
 
+  let is_mdx_comment s =
+    let s = String.strip s in
+    String.is_prefix s ~prefix:"$MDX"
+  ;;
+
   let is_cinaps s = Char.equal s.[0] '$'
   let is_doc_comment s = Char.equal s.[0] '*'
   let is_ignored_comment s = Char.equal s.[0] '_'
 
   let can_appear_in_mli s =
-    is_doc_comment s || is_ignored_comment s || is_cr_comment s || is_cinaps s
+    is_doc_comment s
+    || is_ignored_comment s
+    || is_cr_comment s
+    || is_cinaps s
+    || is_mdx_comment s
   ;;
 
   let syntax_check_doc_comment ~loc comment =
@@ -597,7 +605,7 @@ let () =
       check#structure st;
       if !check_comments then Comments_checking.check_all ();
       st)
-    (* note: we do not use ~impl because we want the check to run before ppx
+      (* note: we do not use ~impl because we want the check to run before ppx
        processing (ppx_cold will replace `[@cold]` with `[@inline never] ...`)*)
     ~lint_impl:(fun st -> enforce_cold#structure st [])
 ;;
